@@ -1,12 +1,19 @@
-krige.uk <- function(y, V, Vp, Vop, X, Xp, nsim = 0, Ve.diag = NULL, method = "eigen")
+krige.uk <- function(y, V, Vp, Vop, X, Xp, ...)
 {
-	# check arguments
-	ins <- krige_arg_check(y, V, Vp, Vop, X, Xp, m = 0, nsim, Ve.diag, method)
+	# Check arguments.  Create unspecified arguments if needed.
+	nsim <- 0; Ve.diag <- NULL; method <- "eigen"; level <- NULL; alternative <- NULL
+	arglist <- list(...)
+	argnames <- names(arglist)
+	if("nsim" %in% argnames){ nsim <- arglist$nsim }
+	if("Ve.diag" %in% argnames){ Ve.diag <- arglist$Ve.diag }
+	if("method" %in% argnames){ method <- arglist$method }
+	if("level" %in% argnames){ level <- arglist$level }
+	if("alternative" %in% argnames){ alternative <- arglist$alternative }
+	ins <- krige_arg_check(y, V, Vp, Vop, X, Xp, m = 0, nsim, Ve.diag, method, 
+		level, alternative)
 
 	###compute matrix products for future use
-	#compute Vi*X
 	ViX <- solve(V, X)
-	#compute X'*Vi*X
 	XtViX <- crossprod(ViX, X)
 	
 	#compute gls estimates of regression coefficients
@@ -15,15 +22,16 @@ krige.uk <- function(y, V, Vp, Vop, X, Xp, nsim = 0, Ve.diag = NULL, method = "e
 	#compute kriging weights
 	w <- solve(V, Vop - X%*%solve(XtViX, crossprod(X, solve(V, Vop)) - t(Xp)))
 
-	#blup for Yp
+	#blup for yp
 	pred <- crossprod(w, y)
 	
-	#variance of (Yp - pred)
+	#variance of (yp - pred)
 	mspe <- colSums((V %*% w) * w) - 2 * colSums(w * Vop) + diag(Vp)
 
 	out <- list(pred = pred, mspe = mspe, coeff = coeff, 
 		vcov.coef = solve(XtViX))
 
+	# generate conditional realizations if nsim > 0
 	if(nsim > 0)
 	{
 		# determine number of observed and predicted data values
@@ -46,15 +54,26 @@ krige.uk <- function(y, V, Vp, Vop, X, Xp, nsim = 0, Ve.diag = NULL, method = "e
 			matrix(rnorm(n * nsim, sd = sqrt(Ve.diag)), nrow = n, ncol = nsim)
 	
 		# Create conditional realizations
-		out$simulations <- newsim[-(1:n),] + crossprod(w, newZ)
+		sim <- newsim[-(1:n),] + crossprod(w, newZ)
+		
+		out$sim <- sim
 	}
 	return(out)
 }
 
-krige.ok <- function(y, V, Vp, Vop, nsim = 0, Ve.diag = NULL, method = "eigen")
+krige.ok <- function(y, V, Vp, Vop, ...)
 {
-	# check arguments, create appropriate values of rws and method for .Call
-	ins <- krige_arg_check(y, V, Vp, Vop, X = NULL, Xp = NULL, m = 0, nsim, Ve.diag, method)
+	# Check arguments.  Create unspecified arguments if needed.
+	nsim <- 0; Ve.diag <- NULL; method <- "eigen"; level <- NULL; alternative <- NULL
+	arglist <- list(...)
+	argnames <- names(arglist)
+	if("nsim" %in% argnames){ nsim <- arglist$nsim }
+	if("Ve.diag" %in% argnames){ Ve.diag <- arglist$Ve.diag }
+	if("method" %in% argnames){ method <- arglist$method }
+	if("level" %in% argnames){ level <- arglist$level }
+	if("alternative" %in% argnames){ alternative <- arglist$alternative }
+	ins <- krige_arg_check(y, V, Vp, Vop, X = NULL, Xp = NULL, m = 0, nsim, Ve.diag, method, 
+		level, alternative)
 
 	out <- .Call( "krige_ok", ys = y, Vs = V, Vps = Vp, Vops = Vop, 
 		nsims = nsim, Vediags = ins$Ve.diag, method = ins$method, 
@@ -67,10 +86,19 @@ krige.ok <- function(y, V, Vp, Vop, nsim = 0, Ve.diag = NULL, method = "eigen")
 	return(out)
 }
 
-krige.sk <- function(y, V, Vp, Vop, m = 0, nsim = 0, Ve.diag = NULL, method = "eigen")
+krige.sk <- function(y, V, Vp, Vop, m = 0, ...)
 {
-	# check arguments, create appropriate values of rws and method for .Call
-	ins <- krige_arg_check(y, V, Vp, Vop, X = NULL, Xp = NULL, m = 0, nsim, Ve.diag, method)
+	# Check arguments.  Create unspecified arguments if needed.
+	nsim <- 0; Ve.diag <- NULL; method <- "eigen"; level <- NULL; alternative <- NULL
+	arglist <- list(...)
+	argnames <- names(arglist)
+	if("nsim" %in% argnames){ nsim <- arglist$nsim }
+	if("Ve.diag" %in% argnames){ Ve.diag <- arglist$Ve.diag }
+	if("method" %in% argnames){ method <- arglist$method }
+	if("level" %in% argnames){ level <- arglist$level }
+	if("alternative" %in% argnames){ alternative <- arglist$alternative }
+	ins <- krige_arg_check(y, V, Vp, Vop, X = NULL, Xp = NULL, m = m, nsim, Ve.diag, method, 
+		level, alternative)
 
 	out <- .Call( "krige_sk", ys = y, Vs = V, Vps = Vp, Vops = Vop, ms = m, 
 		nsims = nsim, Vediags = ins$Ve.diag, method = ins$method, 
